@@ -165,7 +165,7 @@ notes_io(int save)
   char t[STRING_BUF_SIZE];
   FILE *file;
   int pid = (int) getpid();
-  static int sizes[6];
+  static int sizes[7];
   sizes[0] = size_0;
   sizes[1] = size_1;
   sizes[2] = size_2;
@@ -219,7 +219,11 @@ notes_io(int save)
     }
   } else {  /*** LOAD ***/
     int rev;
+    void *dummy;
+    int dummy2;
 
+    (void) dummy;
+    (void) dummy2;
     if (!fread(s, 5, 1, file) || strncmp(s, header, 4)) {  /* check header */
       fprintf(stderr, "Fatal error: Corrupt data file encountered.\n"
         "Delete `~%s' to start over.\n", rc_file_name);
@@ -238,30 +242,30 @@ notes_io(int save)
       exit(EXIT_FAILURE);
     }
 
-    fgets(opts.font, sizeof(opts.font), file);
+    dummy = fgets(opts.font, sizeof(opts.font), file);
     if (strlen(opts.font) && opts.font[strlen(opts.font)-1] == '\n')
       opts.font[strlen(opts.font)-1] = '\0';
 
     if (rev >= 4) {
-      fgets(opts.theme, sizeof(opts.theme), file);
+      dummy = fgets(opts.theme, sizeof(opts.theme), file);
       if (strlen(opts.theme) && opts.theme[strlen(opts.theme)-1] == '\n')
         opts.theme[strlen(opts.theme)-1] = '\0';
     }
     if (rev >= 6) {
-      fgets(opts.alarm_cmd, sizeof(opts.alarm_cmd), file);
+      dummy = fgets(opts.alarm_cmd, sizeof(opts.alarm_cmd), file);
       if (strlen(opts.alarm_cmd) && opts.alarm_cmd[strlen(opts.alarm_cmd)-1] ==
         '\n')
       {
         opts.alarm_cmd[strlen(opts.alarm_cmd)-1] = '\0';
       }
     }
-    if (rev >= 3) fread(&pid, sizeof(pid), 1, file);  /* last writer's PID */
+    if (rev >= 3) dummy2 = fread(&pid, sizeof(pid), 1, file);  /* last writer's PID */
     if (rev >= 2)  /* state.state_bits */
-      fread(&state.state_bits, sizeof(state.state_bits), 1, file);
+      dummy2 = fread(&state.state_bits, sizeof(state.state_bits), 1, file);
     else
       state.state_bits = 0;
     if (rev >= 5) /* counter */
-      fread(&state.counter, sizeof(state.counter), 1, file);
+      dummy2 = fread(&state.counter, sizeof(state.counter), 1, file);
     else
       state.counter = 0;
 
@@ -686,7 +690,7 @@ action(actions type, const void *data)
         if (strlen(data) >= sizeof(opts.font)) {
           /* avoid trouble when retrieving saved data... */
           fprintf(stderr, "Fatal error: Specified font descriptor exceeds "
-            "buffer size of %d bytes.\n", sizeof(opts.font));
+            "buffer size of %lu bytes.\n", sizeof(opts.font));
           exit(EXIT_FAILURE);
         }
         strcpy(opts.font, data);
@@ -702,7 +706,7 @@ action(actions type, const void *data)
       } else {
         if (strlen(data) >= sizeof(opts.theme)) {
           fprintf(stderr, "Fatal error: Specified theme file location exceeds "
-            "buffer size of %d bytes.\n", sizeof(opts.theme));
+            "buffer size of %lu bytes.\n", sizeof(opts.theme));
           exit(EXIT_FAILURE);
         }
         strcpy(opts.theme, data);
@@ -721,7 +725,7 @@ action(actions type, const void *data)
       } else {
         if (strlen(data) >= sizeof(opts.alarm_cmd)) {
           fprintf(stderr, "Fatal error: Specified theme file location exceeds "
-            "buffer size of %d bytes.\n", sizeof(opts.alarm_cmd));
+            "buffer size of %lu bytes.\n", sizeof(opts.alarm_cmd));
           exit(EXIT_FAILURE);
         }
         strcpy(opts.alarm_cmd, data);
@@ -973,26 +977,32 @@ parse_argv(int argc, char **argv)
       case 'h': help();
       case 'i': action(M_INFO, 0);
       case 'v':
-        printf("wmpinboard v" VERSION "\n\ncompile-time configuration:\n"
-          "  - maximal number of notes is %d\n"
 #if TIMEOUT == 0
-          "  - edit mode timeout is disabled by default\n"
+#define PRINT1    "  - edit mode timeout is disabled by default\n"
 #else
-          "  - default edit mode timeout is %d seconds\n"
+#define PRINT1    "  - default edit mode timeout is %d seconds\n"
 #endif
-          "  - wear & tear of notes (creases) is "
 #ifdef CREASES
-          "enabled\n"
+#define PRINT2    "enabled\n"
 #else
-          "disabled\n"
+#define PRINT2    "disabled\n"
 #endif
 #ifndef FUNSTUFF
-          "  - FUNSTUFF is disabled  :-/\n"
+#define PRINT3    "  - FUNSTUFF is disabled  :-/\n"
+#else
+#define PRINT3
 #endif
-          , MAX_NOTES
 #if TIMEOUT != 0
-          , TIMEOUT
+#define PRINT4    , TIMEOUT
 #endif
+        printf("wmpinboard v" VERSION "\n\ncompile-time configuration:\n"
+          "  - maximal number of notes is %d\n"
+	  PRINT1
+          "  - wear & tear of notes (creases) is "
+          PRINT2
+          PRINT3
+          , MAX_NOTES
+          PRINT4
           );
         exit(EXIT_SUCCESS);
       default : exit(EXIT_FAILURE);
@@ -1262,7 +1272,7 @@ animate_abar(int in)
 void
 animate_note(int style)
 {
-  static const int seq[10] = { 2, 3, 6, 9, 12, 12, 9, 6, 3, 2 };
+  static const int seq[11] = { 2, 3, 6, 9, 12, 12, 9, 6, 3, 2, 0 };
   XRectangle mask[5] = { { 6, 2, 52, 60 }, { 0, 0, 0, 0 }, { 0, 0, 0, 0 },
     { 0, 0, 0, 0 }, { 0, 0, 0, 0 } };
   int i, j;
@@ -1532,7 +1542,7 @@ handle_ButtonRelease(XEvent *event)
         }
       } else {  /* moved */
         if (state.cur_note >= 0) {
-          if (string_empty(ndata[state.cur_note].text, 0)) {  /* new note */
+          if (note_empty(state.cur_note)) {  /* new note */
             animate_note(4);
             set_kbfocus(1);
             set_mode(M_EDIT);
@@ -1711,7 +1721,14 @@ handle_ButtonRelease(XEvent *event)
         {
           if (state.abar_pressed < 4) {  /* clicked on number */
             char c = state.a_edit[state.abar_pressed];
-            char delta = state.button == 1 ? 1 : -1;
+            char delta;
+            switch (state.button) {
+              case 1:  delta = 1;   break;  /* Left mouse button */
+              case 3:  delta = -1;  break;  /* Right mouse button */
+              case 4:  delta = 1;   break;  /* Scrollwheel up */
+              case 5:  delta = -1;  break;  /* Scrollwheel down */
+              default: delta = 0;   break;  /* Unknown button; ignore */
+            }
 
             switch (state.abar_pressed) {
               case 0:  c = (24+c+delta)%24;  break;
@@ -1849,7 +1866,7 @@ void
 handle_KeyPress(XEvent *event)
 {
   KeySym ksym;
-  unsigned char ch[4];
+  char ch[4];
   char *s;
   int i, j = 0;
 
@@ -1910,8 +1927,9 @@ handle_KeyPress(XEvent *event)
     }
   } else {
     if (InputContext) {
-      j = XmbLookupString(InputContext, &event->xkey, (char*) ch, sizeof(ch),
-        &ksym, 0);
+      Status status_return;
+      j = XmbLookupString(InputContext, &event->xkey, ch, sizeof(ch),
+        &ksym, &status_return);
     } else {
       j = XLookupString(&event->xkey, (char*) ch, sizeof(ch), &ksym,
         &state.compose);
@@ -2120,7 +2138,7 @@ main(int argc, char **argv)
   init();                  /* initialize X window */
   XSetCommand(display, mainwin, argv, argc);
   XMapWindow(display, mainwin);
-  init_xlocale();          /* initialize input context */
+/*  init_xlocale();          * initialize input context */
 
   /* initialize internal images, palette, cursors */
   bbar = get_xpm((char**) bbar_xpm);
@@ -2241,7 +2259,8 @@ main(int argc, char **argv)
         char buf[STRING_BUF_SIZE+2];
         strcpy(buf, opts.alarm_cmd);
         strcat(buf, " &");
-        system(buf);
+        if (system(buf))
+		exit(1);
       }
       prepare_alarm_anim();
       state.alarm.phase = 0;
